==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigRequestsLimitsFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageRegistryConfigRequestsLimitsFluent<A extends ImageRegistryConfigRequestsLimitsFluent<A>> extends BaseFluent<A>{
  public ImageRegistryConfigRequestsLimitsFluent() {
  }
  
  public ImageRegistryConfigRequestsLimitsFluent(ImageRegistryConfigRequestsLimits instance) {
    this.copyInstance(instance);
  }
  private Integer maxInQueue;
  private Integer maxRunning;
  private Duration maxWaitInQueue;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageRegistryConfigRequestsLimits instance) {
    instance = (instance != null ? instance : new ImageRegistryConfigRequestsLimits());
  
    if (instance != null) {
        this.withMaxInQueue(instance.getMaxInQueue());
        this.withMaxRunning(instance.getMaxRunning());
        this.withMaxWaitInQueue(instance.getMaxWaitInQueue());
        this.withMaxInQueue(instance.getMaxInQueue());
        this.withMaxRunning(instance.getMaxRunning());
        this.withMaxWaitInQueue(instance.getMaxWaitInQueue());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Integer getMaxInQueue() {
    return this.maxInQueue;
  }
  
  public A withMaxInQueue(Integer maxInQueue) {
    this.maxInQueue=maxInQueue; return (A) this;
  }
  
  public boolean hasMaxInQueue() {
    return this.maxInQueue != null;
  }
  
  public Integer getMaxRunning() {
    return this.maxRunning;
  }
  
  public A withMaxRunning(Integer maxRunning) {
    this.maxRunning=maxRunning; return (A) this;
  }
  
  public boolean hasMaxRunning() {
    return this.maxRunning != null;
  }
  
  public Duration getMaxWaitInQueue() {
    return this.maxWaitInQueue;
  }
  
  public A withMaxWaitInQueue(Duration maxWaitInQueue) {
    this.maxWaitInQueue=maxWaitInQueue; return (A) this;
  }
  
  public boolean hasMaxWaitInQueue() {
    return this.maxWaitInQueue != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigRequestsLimitsFluent that = (ImageRegistryConfigRequestsLimitsFluent) o;
    if (!java.util.Objects.equals(maxInQueue, that.maxInQueue)) return false;
  
    if (!java.util.Objects.equals(maxRunning, that.maxRunning)) return false;
  
    if (!java.util.Objects.equals(maxWaitInQueue, that.maxWaitInQueue)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(maxInQueue,  maxRunning,  maxWaitInQueue,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (maxInQueue != null) { sb.append("maxInQueue:"); sb.append(maxInQueue + ","); }
    if (maxRunning != null) { sb.append("maxRunning:"); sb.append(maxRunning + ","); }
    if (maxWaitInQueue != null) { sb.append("maxWaitInQueue:"); sb.append(maxWaitInQueue + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-miscellaneous-6.9.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigRequestsLimitsFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageRegistryConfigRequestsLimitsFluent<A extends ImageRegistryConfigRequestsLimitsFluent<A>> extends BaseFluent<A>{
  public ImageRegistryConfigRequestsLimitsFluent() {
  }
  
  public ImageRegistryConfigRequestsLimitsFluent(ImageRegistryConfigRequestsLimits instance) {
    this.copyInstance(instance);
  }
  private Integer maxInQueue;
  private Integer maxRunning;
  private Duration maxWaitInQueue;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageRegistryConfigRequestsLimits instance) {
    instance = (instance != null ? instance : new ImageRegistryConfigRequestsLimits());
    if (instance != null) {
          this.withMaxInQueue(instance.getMaxInQueue());
          this.withMaxRunning(instance.getMaxRunning());
          this.withMaxWaitInQueue(instance.getMaxWaitInQueue());
          this.withMaxInQueue(instance.getMaxInQueue());
          this.withMaxRunning(instance.getMaxRunning());
          this.withMaxWaitInQueue(instance.getMaxWaitInQueue());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Integer getMaxInQueue() {
    return this.maxInQueue;
  }
  
  public A withMaxInQueue(Integer maxInQueue) {
    this.maxInQueue = maxInQueue;
    return (A) this;
  }
  
  public boolean hasMaxInQueue() {
    return this.maxInQueue != null;
  }
  
  public Integer getMaxRunning() {
    return this.maxRunning;
  }
  
  public A withMaxRunning(Integer maxRunning) {
    this.maxRunning = maxRunning;
    return (A) this;
  }
  
  public boolean hasMaxRunning() {
    return this.maxRunning != null;
  }
  
  public Duration getMaxWaitInQueue() {
    return this.maxWaitInQueue;
  }
  
  public A withMaxWaitInQueue(Duration maxWaitInQueue) {
    this.maxWaitInQueue = maxWaitInQueue;
    return (A) this;
  }
  
  public boolean hasMaxWaitInQueue() {
    return this.maxWaitInQueue != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigRequestsLimitsFluent that = (ImageRegistryConfigRequestsLimitsFluent) o;
    if (!java.util.Objects.equals(maxInQueue, that.maxInQueue)) return false;
    if (!java.util.Objects.equals(maxRunning, that.maxRunning)) return false;
    if (!java.util.Objects.equals(maxWaitInQueue, that.maxWaitInQueue)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(maxInQueue,  maxRunning,  maxWaitInQueue,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (maxInQueue != null) { sb.append("maxInQueue:"); sb.append(maxInQueue + ","); }
    if (maxRunning != null) { sb.append("maxRunning:"); sb.append(maxRunning + ","); }
    if (maxWaitInQueue != null) { sb.append("maxWaitInQueue:"); sb.append(maxWaitInQueue + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
